/// <reference types="node" />
import { EventEmitter } from 'events';
import { Duplex } from 'stream';
export interface Connection extends EventEmitter {
    on(event: 'token', handler: (token: Buffer) => void): this;
}
/**
 * Wrapper for streams that emits "token".
 */
export declare class Connection extends EventEmitter {
    private socket;
    private buffer;
    constructor(socket: Duplex);
    /**
     * Is true if the underlying socket is not writable.
     */
    readonly isDead: boolean;
    /**
     * Writes a message to the socket. Returns true if the message was written to the socket.
     * @param data The buffer to transmit.
     */
    send(data: Buffer): boolean;
    /**
     * Close the connection.
     */
    close(): boolean;
    /**
     * Initially apply all events.
     */
    private applyEvents();
    /**
     * Parses and emits all tokens from the buffer.
     */
    private parse();
}
